import PropTypes from 'prop-types';
import { compose, withState, withHandlers } from 'recompose';
import { getId } from '../../../lib/get_id';
import { notify } from '../../../lib/notify';
import { WorkpadUpload as Component } from './workpad_upload';

export const WorkpadUpload = compose(
  withState('isDropping', 'setDropping', false),
  withHandlers({
    onDropAccepted: ({ onUpload, setDropping }) => ([file]) => {
      // TODO: Clean up this file, this loading stuff can, and should be, abstracted
      const reader = new FileReader();

      // handle reading the uploaded file
      reader.onload = () => {
        try {
          const workpad = JSON.parse(reader.result);
          workpad.id = getId('workpad');
          onUpload(workpad);
        } catch (e) {
          notify.error(e, { title: `Couldn't upload '${file.name || 'file'}'` });
        }
      };

      // read the uploaded file
      reader.readAsText(file);
      setDropping(false);
    },
    onDropRejected: ({ setDropping }) => ([file]) => {
      notify.warning('Only JSON files are accepted', {
        title: `Couldn't upload '${file.name || 'file'}'`,
      });
      setDropping(false);
    },
  })
)(Component);

WorkpadUpload.propTypes = {
  onUpload: PropTypes.func.isRequired,
};
